==> nocc-1.9.1.tbz: www/nocc/lang/he.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: he.php 2376 2011-01-22 19:46:26Z gerundt $
 */
/** Hebrew (עברית)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Tzafrir Cohen <tzafrir@technion.ac.il>
 * @author YaronSh
 */

$lang_locale = 'he_IL.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'שדה שם המשתמש ריק';
$err_passwd_empty = 'שדה הסיסמה ריק';
$alt_delete = 'מחיקת ההודעות המסומנות';
$alt_delete_one = 'מחיקת ההודעה';
$alt_new_msg = 'הודעה חדשה';
$alt_reply = 'תשובה';
$alt_reply_all = 'תשובה לכל';
$alt_forward = 'העברה';
$alt_next = 'הבא';
$alt_prev = 'הקודם';
$title_next_page = 'הדף הבא';
$title_prev_page = 'הדף הקודם';
$title_next_msg = 'ההודעה הבאה';
$title_prev_msg = 'ההודעות הבאות';
$html_theme_label = 'ערכת נושא:';
$html_welcome = 'ברוכים הבאים אל %1$s';
$html_login = 'שם המשתמש';
$html_submit = 'התחברות';
$html_help = 'עזרה';
$html_wrong = 'שם המשתמש או הסיסמה שגויים';
$html_retry = 'נסיון נוסף';
$html_remember = 'שמירת ההגדרות';
$html_lang_label = 'שפה:';
$html_msgperpage_label = 'הודעות בדף:';
$html_preferences = 'העדפות';
$html_full_name_label = 'שם מלא:';
$html_email_address_label = 'כתובת דוא"ל:';
$html_bccself = 'Bcc self';
$html_hide_addresses = 'הסתרת כתובות';
$html_outlook_quoting = 'ציטוט בסגנון Outlook';
$html_reply_to = 'תגובה אל';
$html_use_signature = 'שימוש בחתימה';
$html_signature = 'חתימה';
$html_signature_label = 'חתימה:';
$html_reply_leadin_label = 'הקדמה לתגובה:';
$html_prefs_updated = 'ההעדפות עודכנו';
$html_manage_folders_link = 'ניהול תיקיות IMAP';
$html_manage_filters_link = 'ניהול מסנני דוא"ל';
$html_use_graphical_smilies = 'שימוש בחייכנים גרפיים';
$html_sent_folder_label = 'העתקת הודעות שנשלחו לתיקייה יעודית:';
$html_trash_folder_label = 'העברת הודעות שנמחקו אל תיקייה יעודית:';
$html_colored_quotes = 'ציטוטים בצבע';
$html_display_struct = 'הצגת טקסט מעוצב';
$html_send_html_mail = 'שליחת ההודעה במבנה HTML';
$html_folders = 'תיקיות';
$html_folders_create_failed = 'לא ניתן ליצור את התיקייה!';
$html_folders_sub_failed = 'לא ניתן להרשם לתיקייה!';
$html_folders_unsub_failed = 'לא ניתן לבטל את הרישום מהתיקייה!';
$html_folders_rename_failed = 'לא ניתן לשנות את שם התיקייה!';
$html_folders_updated = 'התיקיות עודכנו';
$html_folder_subscribe = 'הרשמה אל';
$html_folder_rename = 'שינוי שם';
$html_folder_create = 'יצירת תיקייה חדשה בשם';
$html_folder_remove = 'ביטול ההרשמה מ';
$html_folder_delete = 'מחיקה';
$html_folder_to = 'אל';
$html_filter_remove = 'הסרה';
$html_filter_body = 'גוף ההודעה';
$html_filter_subject = 'נושא ההודעה';
$html_filter_to = 'שדה הנמען';
$html_filter_cc = 'שדה העותק';
$html_filter_from = 'השדה מאת';
$html_filter_change_tip = 'כדי לשנות מסנן יש פשוט לשכתב עליו.';
$html_reapply_filters = 'החלת כל המסננים מחדש';
$html_filter_contains = 'מכילה';
$html_filter_name = 'שם המסנן';
$html_filter_action = 'פעולת המסנן';
$html_filter_moveto = 'העברה אל';
$html_select_one = '--בחרו באחד--';
$html_and = 'וגם';
$html_new_msg_in = 'הודעות חדשות תחת';
$html_or = 'או';
$html_move = 'העברה';
$html_copy = 'העתקה';
$html_messages_to = 'ההודעות הנבחרות אל';
$html_gotopage = 'מעבר לדף';
$html_gotofolder = 'מעבר לתיקייה';
$html_other_folders = 'רשימת התיקיות';
$html_page = 'דף';
$html_of = 'מתוך';
$html_view_header = 'הצגת כותרות';
$html_remove_header = 'הסתרת כותרות';
$html_inbox = 'תיבת הדואר';
$html_new_msg = 'כתיבה';
$html_reply = 'תשובה';
$html_reply_short = 'תגובה:';
$html_reply_all = 'תשובה לכל';
$html_forward = 'העברה';
$html_forward_short = 'העברה:';
$html_forward_info = 'ההודעה המועברת תשלח כקובץ מצורף להודעה זו.';
$html_delete = 'מחיקה';
$html_new = 'חדש';
$html_mark = 'מחיקה';
$html_att_label = 'קובץ מצורף:';
$html_atts_label = 'קבצים מצורפים:';
$html_unknown = '[לא ידוע]';
$html_attach = 'צירוף';
$html_attach_forget = 'חייבים לצרף קובץ לפני שליחת ההודעה!';
$html_attach_delete = 'ביטול המסומנים';
$html_attach_none = 'עליכם לבחור קובץ לצירוף!';
$html_sort_by = 'מיון לפי';
$html_sort = 'מיון';
$html_from = 'מאת';
$html_from_label = 'מאת:';
$html_subject = 'נושא';
$html_subject_label = 'נושא:';
$html_date = 'תאריך';
$html_date_label = 'תאריך:';
$html_sent_label = 'נשלח:';
$html_wrote = 'כתב';
$html_size = 'גודל';
$html_totalsize = 'גודל כולל';
$html_kb = 'ק"ב';
$html_mb = 'מ"ב';
$html_gb = 'ג"ב';
$html_bytes = 'בתים';
$html_filename = 'שם הקובץ';
$html_to = 'אל';
$html_to_label = 'נמען:';
$html_cc = 'העתק';
$html_cc_label = 'עותק:';
$html_bcc_label = 'עותק מוסתר:';
$html_nosubject = '[ללא נושא]';
$html_send = 'שליחה';
$html_cancel = 'ביטול';
$html_no_mail = 'אין הודעות.';
$html_logout = 'יציאה';
$html_msg = 'הודעה';
$html_msgs = 'הודעות';
$html_configuration = 'שרת זה אינו מוגדר כראוי!';
$html_priority = 'עדיפות';
$html_priority_label = 'עדיפות:';
$html_lowest = 'נמוכה ביותר';
$html_low = 'נמוכה';
$html_normal = 'רגילה';
$html_high = 'גבוהה';
$html_highest = 'גבוהה ביותר';
$html_receipt = 'בקשת אישור קבלה';
$html_select = 'בחירה';
$html_select_all = 'הפיכת הבחירה';
$html_loading_image = 'התמונה נטענת';
$html_send_confirmed = 'הודעת הדוא"ל שלכם התקבלה למשלוח';
$html_no_sendaction = 'לא צוינה פעולה. נסו להפעיל את ה־JavaScript.';
$html_error_occurred = 'ארעה שגיאה';
$html_prefs_file_error = 'לא ניתן לפתוח את ההעדפות לכתיבה.';
$html_wrap = 'מספר התווים לגלישה בהודעות יוצאות:';
$html_wrap_none = 'ללא גלישה';
$html_usenet_separator = 'מפריד Usenet‏ ("‎-- \n") לפני החתימה';
$html_mark_as = 'סימון בתור';
$html_read = 'נקראה';
$html_unread = 'לא נקראה';
$html_encoding_label = 'קידוד תווים:';
$html_add = 'הוספה';
$html_contacts = 'אנשי הקשר של %1$s';
$html_modify = 'שינוי';
$html_back = 'חזרה';
$html_contact_add = 'הוספת איש קשר חדש';
$html_contact_mod = 'שינוי איש קשר';
$html_contact_first = 'שם פרטי';
$html_contact_last = 'שם משפחה';
$html_contact_nick = 'כינוי';
$html_contact_mail = 'דוא"ל';
$html_contact_list = 'רשימת אנשי הקשר של %1$s';
$html_contact_del = 'מרשימת אנשי הקשר';
$html_contact_count = '%1$d אנשי קשר';
$html_contact_err2 = 'לא ניתן להוסיף איש קשר חדש';
$html_del_msg = 'האם למחוק את ההודעה הנבחרת?';
$html_down_mail = 'הורדה';
$original_msg = '-- הודעה מקורית --';
$to_empty = 'לשדה ה־\'נמען\' אסור להיות ריק!';
$html_images_display = 'הצגת תמונות';
$html_smtp_error_unexpected = 'תגובת SMTP בלתי צפויה:';
$html_search = 'חיפוש';

==> nocc-1.9.3.tbz: www/nocc/lang/he.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: he.php 2531 2012-03-01 15:52:20Z siebrand $
 */
/** Hebrew (עברית)
 * 
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Amire80
 * @author Tzafrir Cohen <tzafrir@technion.ac.il>
 * @author YaronSh
 */

$lang_locale = 'he_IL.UTF-8';
$lang_dir = 'rtl';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%H:%M';
$err_user_empty = 'שדה שם המשתמש ריק';
$err_passwd_empty = 'שדה הסיסמה ריק';
$alt_delete = 'מחיקת ההודעות המסומנות';
$alt_delete_one = 'מחיקת ההודעה';
$alt_new_msg = 'הודעה חדשה';
$alt_reply = 'תשובה';
$alt_reply_all = 'תשובה לכל';
$alt_forward = 'העברה';
$alt_next = 'הבא';
$alt_prev = 'הקודם';
$title_next_page = 'הדף הבא';
$title_prev_page = 'הדף הקודם';
$title_next_msg = 'ההודעה הבאה';
$title_prev_msg = 'ההודעות הבאות';
$html_theme_label = 'ערכת נושא:';
$html_welcome = 'ברוכים הבאים אל %1$s';
$html_login = 'כניסה';
$html_submit = 'התחברות';
$html_help = 'עזרה';
$html_wrong = 'שם המשתמש או הסיסמה שגויים';
$html_retry = 'נסיון נוסף';
$html_remember = 'שמירת ההגדרות';
$html_lang_label = 'שפה:';
$html_msgperpage_label = 'הודעות בדף:';
$html_preferences = 'העדפות';
$html_full_name_label = 'שם מלא:';
$html_email_address_label = 'כתובת דוא"ל:';
$html_bccself = 'עותק מוסתר לעצמך';
$html_hide_addresses = 'הסתרת כתובות';
$html_outlook_quoting = 'ציטוט בסגנון Outlook';
$html_reply_to = 'תגובה אל';
$html_use_signature = 'שימוש בחתימה';
$html_signature = 'חתימה';
$html_signature_label = 'חתימה:';
$html_reply_leadin_label = 'הקדמה לתגובה:';
$html_prefs_updated = 'ההעדפות עודכנו';
$html_manage_folders_link = 'ניהול תיקיות IMAP';
$html_manage_filters_link = 'ניהול מסנני דוא"ל';
$html_use_graphical_smilies = 'שימוש בחייכנים גרפיים';
$html_sent_folder_label = 'העתקת הודעות שנשלחו לתיקייה יעודית:';
$html_trash_folder_label = 'העברת הודעות שנמחקו אל תיקייה יעודית:';
$html_colored_quotes = 'ציטוטים בצבע';
$html_display_struct = 'הצגת טקסט מעוצב';
$html_send_html_mail = 'שליחת ההודעה במבנה HTML';
$html_folders = 'תיקיות';
$html_folders_create_failed = 'לא ניתן ליצור את התיקייה!';
$html_folders_sub_failed = 'לא ניתן להרשם לתיקייה!';
$html_folders_unsub_failed = 'לא ניתן לבטל את הרישום מהתיקייה!';
$html_folders_rename_failed = 'לא ניתן לשנות את שם התיקייה!';
$html_folders_updated = 'התיקיות עודכנו';
$html_folder_subscribe = 'הרשמה אל';
$html_folder_rename = 'שינוי שם';
$html_folder_create = 'יצירת תיקייה חדשה בשם';
$html_folder_remove = 'ביטול ההרשמה מ';
$html_folder_delete = 'מחיקה';
$html_folder_to = 'אל';
$html_filter_remove = 'הסרה';
$html_filter_body = 'גוף ההודעה';
$html_filter_subject = 'נושא ההודעה';
$html_filter_to = 'שדה הנמען';
$html_filter_cc = 'שדה העותק';
$html_filter_from = 'השדה מאת';
$html_filter_change_tip = 'כדי לשנות מסנן יש פשוט לשכתב עליו.';
$html_reapply_filters = 'החלת כל המסננים מחדש';
$html_filter_contains = 'מכילה';
$html_filter_name = 'שם המסנן';
$html_filter_action = 'פעולת המסנן';
$html_filter_moveto = 'העברה אל';
$html_select_one = '--בחרו באחד--';
$html_and = 'וגם';
$html_new_msg_in = 'הודעות חדשות תחת';
$html_or = 'או';
$html_move = 'העברה';
$html_copy = 'העתקה';
$html_messages_to = 'ההודעות הנבחרות אל';
$html_gotopage = 'מעבר לדף';
$html_gotofolder = 'מעבר לתיקייה';
$html_other_folders = 'רשימת התיקיות';
$html_page = 'דף';
$html_of = 'מתוך';
$html_view_header = 'הצגת כותרות';
$html_remove_header = 'הסתרת כותרות';
$html_inbox = 'תיבת הדואר';
$html_new_msg = 'כתיבה';
$html_reply = 'תשובה';
$html_reply_short = 'תגובה:';
$html_reply_all = 'תשובה לכל';
$html_forward = 'העברה';
$html_forward_short = 'העברה:';
$html_forward_info = 'ההודעה המועברת תשלח כקובץ מצורף להודעה זו.';
$html_delete = 'מחיקה';
$html_new = 'חדש';
$html_mark = 'מחיקה';
$html_att_label = 'קובץ מצורף:';
$html_atts_label = 'קבצים מצורפים:';
$html_unknown = '[לא ידוע]';
$html_attach = 'צירוף';
$html_attach_forget = 'חייבים לצרף קובץ לפני שליחת ההודעה!';
$html_attach_delete = 'ביטול המסומנים';
$html_attach_none = 'עליכם לבחור קובץ לצירוף!';
$html_sort_by = 'מיון לפי';
$html_sort = 'מיון';
$html_from = 'מאת';
$html_from_label = 'מאת:';
$html_subject = 'נושא';
$html_subject_label = 'נושא:';
$html_date = 'תאריך';
$html_date_label = 'תאריך:';
$html_sent_label = 'נשלח:';
$html_wrote = 'כתב';
$html_size = 'גודל';
$html_totalsize = 'גודל כולל';
$html_kb = 'ק"ב';
$html_mb = 'מ"ב';
$html_gb = 'ג"ב';
$html_bytes = 'בתים';
$html_filename = 'שם הקובץ';
$html_to = 'אל';
$html_to_label = 'נמען:';
$html_cc = 'העתק';
$html_cc_label = 'עותק:';
$html_bcc_label = 'עותק מוסתר:';
$html_nosubject = '[ללא נושא]';
$html_send = 'שליחה';
$html_cancel = 'ביטול';
$html_no_mail = 'אין הודעות.';
$html_logout = 'יציאה';
$html_msg = 'הודעה';
$html_msgs = 'הודעות';
$html_configuration = 'שרת זה אינו מוגדר כראוי!';
$html_priority = 'עדיפות';
$html_priority_label = 'עדיפות:';
$html_lowest = 'נמוכה ביותר';
$html_low = 'נמוכה';
$html_normal = 'רגילה';
$html_high = 'גבוהה';
$html_highest = 'גבוהה ביותר';
$html_receipt = 'בקשת אישור קבלה';
$html_select = 'בחירה';
$html_select_all = 'הפיכת הבחירה';
$html_loading_image = 'התמונה נטענת';
$html_send_confirmed = 'הודעת הדוא"ל שלכם התקבלה למשלוח';
$html_no_sendaction = 'לא צוינה פעולה. נסו להפעיל את ה־JavaScript.';
$html_error_occurred = 'ארעה שגיאה';
$html_prefs_file_error = 'לא ניתן לפתוח את ההעדפות לכתיבה.';
$html_wrap = 'מספר התווים לגלישה בהודעות יוצאות:';
$html_wrap_none = 'ללא גלישה';
$html_usenet_separator = 'מפריד Usenet‏ ("‎-- \n") לפני החתימה';
$html_mark_as = 'סימון בתור';
$html_read = 'נקראה';
$html_unread = 'לא נקראה';
$html_encoding_label = 'קידוד תווים:';
$html_add = 'הוספה';
$html_contacts = 'אנשי הקשר של %1$s';
$html_modify = 'שינוי';
$html_back = 'חזרה';
$html_contact_add = 'הוספת איש קשר חדש';
$html_contact_mod = 'שינוי איש קשר';
$html_contact_first = 'שם פרטי';
$html_contact_last = 'שם משפחה';
$html_contact_nick = 'כינוי';
$html_contact_mail = 'דוא"ל';
$html_contact_list = 'רשימת אנשי הקשר של %1$s';
$html_contact_del = 'מרשימת אנשי הקשר';
$html_contact_count = '%1$d אנשי קשר';
$html_contact_err2 = 'לא ניתן להוסיף איש קשר חדש';
$html_del_msg = 'האם למחוק את ההודעה הנבחרת?';
$html_down_mail = 'הורדה';
$original_msg = '-- הודעה מקורית --';
$to_empty = 'לשדה ה־\'נמען\' אסור להיות ריק!';
$html_images_display = 'הצגת תמונות';
$html_smtp_error_unexpected = 'תגובת SMTP בלתי צפויה:';
$html_search = 'חיפוש';
